@@ -186,8 +186,7 @@ class BaseLogicDelete(BaseCrudMixin,DeleteView):
 
         return super().dispatch(request, *args, **kwargs)
 
-    def post(self,request,model,*args,**kwargs):
-        self.model = model
+    def delete(self,request,*args,**kwargs):
         instance = get_object(self.model,self.kwargs['pk'])
         
         if instance is not None:
